==> estateplat-common-1.1.0-20160803.085537-138-sources.jar: cn/gtmap/estateplat/model/server/core/GdYy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过度数据对应异议信息
 * @author lst
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_yy")
public class GdYy implements Serializable {

    @Id
    private String yyid;
    private String yysx;
    private String proid;

    private Integer iszx;
    private String bdclx;
    private Date gxrq;

    private String djlx;
	private String fj;

    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String bz;//备注

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public String getYyid() {
        return yyid;
    }

    public void setYyid(String yyid) {
        this.yyid = yyid;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }
}

==> estateplat-common-1.1.0-20161031.065341-211-sources.jar: cn/gtmap/estateplat/model/server/core/GdYy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过度数据对应异议信息
 * @author lst
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_yy")
public class GdYy implements Serializable {

    @Id
    private String yyid;
    private String yysx;
    private String proid;

    private Integer iszx;
    private String bdclx;
    private Date gxrq;

    private String djlx;
	private String fj;

    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public String getYyid() {
        return yyid;
    }

    public void setYyid(String yyid) {
        this.yyid = yyid;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
}
